( cd usr/lib ; rm -rf libcdda_interface.so )
( cd usr/lib ; ln -sf libcdda_interface.so.0.9.8 libcdda_interface.so )
( cd usr/lib ; rm -rf libcdda_interface.so.0 )
( cd usr/lib ; ln -sf libcdda_interface.so.0.9.8 libcdda_interface.so.0 )
( cd usr/lib ; rm -rf libcdda_paranoia.so )
( cd usr/lib ; ln -sf libcdda_paranoia.so.0.9.8 libcdda_paranoia.so )
( cd usr/lib ; rm -rf libcdda_paranoia.so.0 )
( cd usr/lib ; ln -sf libcdda_paranoia.so.0.9.8 libcdda_paranoia.so.0 )
